.. atomworks.io documentation master file, created by
   sphinx-quickstart on Sat May 24 22:09:50 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

atomworks documentation
======================

Welcome to **atomworks** — a toolkit for converting, parsing, and manipulating biological structure and sequence data, inspired by the Biotite library. Quickly convert between formats, extract features, and prepare data for machine learning or structural analysis.

.. image:: ./_static/atomworks_datapipelines.svg
   :width: 100%
   :alt: atomworks datapipelines


.. toctree::
   :maxdepth: 2
   :caption: Navigation

   tutorial/index
   installation
   glossary
   api_reference
   auto_examples/index
   contributor_guide